@@ -1,5 +1,6 @@
 use clap::ArgMatches;
 use dotenv::dotenv;
+use log::LevelFilter;
 use sea_orm_codegen::{EntityTransformer, OutputFile};
 use std::{error::Error, fmt::Display, fs, io::Write, path::Path, process::Command};
 
@@ -25,6 +26,7 @@ async fn run_generate_command(matches: &ArgMatches<'_>) -> Result<(), Box<dyn Er
             let url = args.value_of("DATABASE_URL").unwrap();
             let output_dir = args.value_of("OUTPUT_DIR").unwrap();
             let include_hidden_tables = args.is_present("INCLUDE_HIDDEN_TABLES");
+            let expanded_format = args.is_present("EXPANDED_FORMAT");
             let filter_hidden_tables = |table: &str| -> bool {
                 if include_hidden_tables {
                     true
@@ -32,6 +34,12 @@ async fn run_generate_command(matches: &ArgMatches<'_>) -> Result<(), Box<dyn Er
                     !table.starts_with("_")
                 }
             };
+            if args.is_present("VERBOSE") {
+                let _ = ::env_logger::builder()
+                    .filter_level(LevelFilter::Debug)
+                    .is_test(true)
+                    .try_init();
+            }
 
             let table_stmts = if url.starts_with("mysql://") {
                 use sea_schema::mysql::discovery::SchemaDiscovery;
@@ -66,7 +74,7 @@ async fn run_generate_command(matches: &ArgMatches<'_>) -> Result<(), Box<dyn Er
                 panic!("This database is not supported ({})", url)
             };
 
-            let output = EntityTransformer::transform(table_stmts)?.generate();
+            let output = EntityTransformer::transform(table_stmts)?.generate(expanded_format);
 
             let dir = Path::new(output_dir);
             fs::create_dir_all(dir)?;
